pub struct GetResourceDashboardFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetResourceDashboard.
Gets the Live UI/Persistence UI for a session.
Implementations
Sourceimpl GetResourceDashboardFluentBuilder
impl GetResourceDashboardFluentBuilder
Sourcepub fn as_input(&self) -> &GetResourceDashboardInputBuilder
pub fn as_input(&self) -> &GetResourceDashboardInputBuilder
Access the GetResourceDashboard as a reference.
Sourcepub async fn send(
self,
) -> Result<GetResourceDashboardOutput, SdkError<GetResourceDashboardError, HttpResponse>>
pub async fn send( self, ) -> Result<GetResourceDashboardOutput, SdkError<GetResourceDashboardError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetResourceDashboardOutput, GetResourceDashboardError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetResourceDashboardOutput, GetResourceDashboardError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The The Amazon Resource Name (ARN) for a session.
Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The The Amazon Resource Name (ARN) for a session.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The The Amazon Resource Name (ARN) for a session.